==> gigapxy_1.0.2-18-master.x86_64.deb.tar.gz: usr/share/gigapxy/scripts/gigapxy.sh <==
#!/bin/sh
# @(#) Launch script for Gigapxy gws/gng.
#
# Example: sudo GPX_PFX=/opt/gigapxy GWS_OPTIONS=-vvv GNG_OPTIONS=-vvv ./gigapxy.sh start 3
#
#*****************************************************************
# Copyright 2012-2014 Pavel V. Cherenkov (pcherenkov@gigapxy.com)
#
#  This file is part of Gigapxy.
#
#  Gigapxy is commercial software: all rights to it belong
#  to Pavel V. Cherenkov, its author.
#
#*****************************************************************/

errmsg()
{
  echo >&2 $@; exit 1
}


#############################
# Variables
#############################

RM=/bin/rm
MKDIR=/bin/mkdir
CAT=/bin/cat
OSNAME=`uname -s`

# NB: set GPX_PFX to run in a sandbox.

GPX_PIDFILE_DIR=${GPX_PFX}/opt/gigapxy
GPX_LOG_DIR=${GPX_PFX}/var/log/gigapxy
GPX_TMP_DIR=${GPX_PFX}/tmp

case ${OSNAME} in
    FreeBSD)
        GPX_CONFIG_DIR=${GPX_PFX}/usr/local/etc
        GPX_BIN_DIR=${GPX_PFX}/usr/local/bin
        ;;
    Linux)
        GPX_CONFIG_DIR=${GPX_PFX}/etc
        GPX_BIN_DIR=${GPX_PFX}/usr/bin
        ;;
    *) errmsg "${OSNAME} is not supported."
esac

GWS=${GPX_BIN_DIR}/gws
GNG=${GPX_BIN_DIR}/gng

# NB: config for WS and NG could also be in one file.
GWS_CONFIG=${GPX_CONFIG_DIR}/gws.conf
GNG_CONFIG=${GPX_CONFIG_DIR}/gng.conf

GWS_PIDFILE=${GPX_PIDFILE_DIR}/gws.pid
# The template expands to gng1.pid, gng2.pid, etc.
GNG_PIDFILE_TPL=${GPX_PIDFILE_DIR}/gngXX.pid

GWS_LOG=${GPX_LOG_DIR}/gws.log
# The template expands to gng1.log, gng2.log, etc.
GNG_LOG_TPL=${GPX_LOG_DIR}/gngXX.log

# Temporary buffer file.
tmpbuf=${GPX_TMPDIR}/gpxbuf.$$

# Specify any additional command-line options.
GWS_OPTIONS="${GWS_OPTIONS}"
GNG_OPTIONS="${GNG_OPTIONS}"

# Seconds to wait for components to start up.
: ${WAIT_SEC:='1'}


#############################
# Functions
#############################

usage()
{
${CAT} <<__EOM
Usage: $1 start|stop|status [num]
Where:
    num = number of (gng) engines to launch [1..64]

$1: Gigapxy launch script (feel free to modify).
$1 is part of Gigapxy. Gigapxy is Copyright (C) 2012, 2013 Pavel Cherenkov

__EOM
  exit 1
}


check_prerequisites()
{
  [ -x "${GWS}" -a -x ${GNG} ] || \
    errmsg "$0: non-executable/missing gws=[${GWS}] or gng=[${GNG}]"

  if [ ! -d "${GPX_CONFIG_DIR}" ]; then
    errmsg "$0: config directory [${GPX_CONFIG_DIR}] does not exist."
  fi

  if [ ! -d "${GPX_LOG_DIR}" ]; then
    ${MKDIR} -p ${GPX_LOG_DIR} || errmsg "$0: failed to mkdir [${GPX_LOG_DIR}]"
  fi
}

check_pidfile()
{
    fname=$1
    app=${2:-'process'}

    if [ ! -f "${fname}" ]; then
        echo "[${app}] is not running."
        return 1
    fi

    pid=`${CAT} ${fname}`
    if ! kill -0 ${pid} 2>/dev/null; then
        echo "Stale pidfile [${fname}] found; removing."
        ${RM} ${fname}
        return 1
    fi

    echo "${app} [${pid}] is running."
    return 0
}

gxy_start()
{
    check_pidfile ${GWS_PIDFILE} 'GWS' && return 1

    GNG_NUM=${1:-'1'}

    # GWS has to be launched first.
    echo "Starting GWS ..."
    ${GWS} -q ${GWS_OPTIONS} -l ${GWS_LOG} -p ${GWS_PIDFILE}

    i=1
    while [ "$i" -le "${GNG_NUM}" ]; do
        pidfile=`echo ${GNG_PIDFILE_TPL} | sed "s/XX/$i/g"`
        logfile=`echo ${GNG_LOG_TPL} | sed "s/XX/$i/g"`

        ${GNG} -q ${GNG_OPTIONS} -l ${logfile} -p ${pidfile}
        echo "Starting GNG #${i} ..."

        i=`expr $i + 1`
    done

    echo "Pausing for ${WAIT_SEC} second(s)."
    sleep ${WAIT_SEC}

    gws_pid=`${CAT} ${GWS_PIDFILE} 2>/dev/null`
    if [ $? -eq 0 ] && kill -0 ${gws_pid}; then
        echo "GWS [${gws_pid}] STARTED"
    else
        errmsg "GWS [${gws_pid}] FAILED"
    fi

    ng_err=0; i=1
    while [ "$i" -le "${GNG_NUM}" ]; do
        pidfile=`echo ${GNG_PIDFILE_TPL} | sed "s/XX/$i/g"`
        gng_pid=`$CAT ${pidfile}`
        if kill -0 ${gng_pid} 2>/dev/null; then
            echo "GNG [${gng_pid}] STARTED"
        else
            echo "GNG [${gng_pid}] FAILED"
            ng_err=1
        fi

        i=`expr $i + 1`
    done

    if [ "$ng_err" -gt 0 ]; then
        echo "$0: some GNG's could not start, shutting down GWS."
        kill ${gws_pid}
    fi
}

gxy_status()
{
    check_pidfile ${GWS_PIDFILE} 'GWS' || return 1

    ls ${GPX_PIDFILE_DIR}/gng*.pid 2>/dev/null | while read fname; do
        check_pidfile ${fname} 'GNG'
    done
}


gxy_stop()
{
    check_pidfile ${GWS_PIDFILE} 'GWS' || return 1
    if kill ${pid}; then
        echo "GWS [${pid}] stopped."
    else
        echo "GWS [${pid}] FAILED to stop."
    fi

    # if ws.ng.force_shutdown is enabled, GNG's should quit.
    sleep ${WAIT_SEC}

    ls ${GPX_PIDFILE_DIR}/gng*.pid 2>/dev/null | while read fname; do
        check_pidfile ${fname} 'GNG' || return 1
        if kill ${pid}; then
            echo "GNG [${pid}] stopped."
        else
            echo "GNG [${pid}] FAILED to stop."
        fi
    done
}


#############################
# Main
#############################

[ $# -lt 1 ] && usage $0

check_prerequisites

case "$1" in
    'start'|'START')
        ngnum=1
        if [ $# -ge 2 ]; then
            # Number of (gng) engines to launch.
            ngnum=`expr $2 + 0 2>/dev/null`
            [ $? -ne 0 ] && errmsg "$0: invalid parameter format."
            if [ ${ngnum} -lt 1 -o ${ngnum} -gt 64 ]; then
                errmsg "$0: num [${ngnum}] is out of range."
            fi
        fi
        gxy_start ${ngnum}
        ;;

    'stop'|'STOP')
        gxy_stop
        ;;

    'status'|'STATUS')
        gxy_status
        ;;
    *) errmsg "Unrecognized command: $1" ;;
esac


# __EOF__

==> gigapxy_1.0.2-39-master.x86_64.deb.tar.gz: usr/share/gigapxy/scripts/gigapxy.sh <==
#!/bin/sh
# @(#) Launch script for Gigapxy gws/gng.
#
# Example: sudo GPX_PFX=/opt/gigapxy GWS_OPTIONS=-vvv GNG_OPTIONS=-vvv ./gigapxy.sh start 3
#
#*****************************************************************
# Copyright 2012-2014 Pavel V. Cherenkov (pcherenkov@gigapxy.com)
#
#  This file is part of Gigapxy.
#
#  Gigapxy is commercial software: all rights to it belong
#  to Pavel V. Cherenkov, its author.
#
#*****************************************************************/

errmsg()
{
  echo >&2 $@; exit 1
}


#############################
# Variables
#############################

RM=/bin/rm
MKDIR=/bin/mkdir
CAT=/bin/cat
OSNAME=`uname -s`

# NB: set GPX_PFX to run in a sandbox.

GPX_PIDFILE_DIR=${GPX_PFX}/opt/gigapxy
GPX_LOG_DIR=${GPX_PFX}/var/log/gigapxy
GPX_TMP_DIR=${GPX_PFX}/tmp

case ${OSNAME} in
    FreeBSD)
        GPX_CONFIG_DIR=${GPX_PFX}/usr/local/etc
        GPX_BIN_DIR=${GPX_PFX}/usr/local/bin
        ;;
    Linux)
        GPX_CONFIG_DIR=${GPX_PFX}/etc
        GPX_BIN_DIR=${GPX_PFX}/usr/bin
        ;;
    *) errmsg "${OSNAME} is not supported."
esac

GWS=${GPX_BIN_DIR}/gws
GNG=${GPX_BIN_DIR}/gng

# NB: config for WS and NG could also be in one file.
GWS_CONFIG=${GPX_CONFIG_DIR}/gws.conf
GNG_CONFIG=${GPX_CONFIG_DIR}/gng.conf

GWS_PIDFILE=${GPX_PIDFILE_DIR}/gws.pid
# The template expands to gng1.pid, gng2.pid, etc.
GNG_PIDFILE_TPL=${GPX_PIDFILE_DIR}/gngXX.pid

GWS_LOG=${GPX_LOG_DIR}/gws.log
# The template expands to gng1.log, gng2.log, etc.
GNG_LOG_TPL=${GPX_LOG_DIR}/gngXX.log

# Temporary buffer file.
tmpbuf=${GPX_TMPDIR}/gpxbuf.$$

# Specify any additional command-line options.
GWS_OPTIONS="${GWS_OPTIONS}"
GNG_OPTIONS="${GNG_OPTIONS}"

# Seconds to wait for components to start up.
: ${WAIT_SEC:='1'}


#############################
# Functions
#############################

usage()
{
${CAT} <<__EOM
Usage: $1 start|stop|status [num]
Where:
    num = number of (gng) engines to launch [1..64]

$1: Gigapxy launch script (feel free to modify).
$1 is part of Gigapxy. Gigapxy is Copyright (C) 2012, 2013 Pavel Cherenkov

__EOM
  exit 1
}


check_prerequisites()
{
  [ -x "${GWS}" -a -x ${GNG} ] || \
    errmsg "$0: non-executable/missing gws=[${GWS}] or gng=[${GNG}]"

  if [ ! -d "${GPX_CONFIG_DIR}" ]; then
    errmsg "$0: config directory [${GPX_CONFIG_DIR}] does not exist."
  fi

  if [ ! -d "${GPX_LOG_DIR}" ]; then
    ${MKDIR} -p ${GPX_LOG_DIR} || errmsg "$0: failed to mkdir [${GPX_LOG_DIR}]"
  fi
}

check_pidfile()
{
    fname=$1
    app=${2:-'process'}

    if [ ! -f "${fname}" ]; then
        echo "[${app}] is not running."
        return 1
    fi

    pid=`${CAT} ${fname}`
    if ! kill -0 ${pid} 2>/dev/null; then
        echo "Stale pidfile [${fname}] found; removing."
        ${RM} ${fname}
        return 1
    fi

    echo "${app} [${pid}] is running."
    return 0
}

gxy_start()
{
    check_pidfile ${GWS_PIDFILE} 'GWS' && return 1

    GNG_NUM=${1:-'1'}

    # GWS has to be launched first.
    echo "Starting GWS ..."
    ${GWS} -q ${GWS_OPTIONS} -l ${GWS_LOG} -p ${GWS_PIDFILE}

    i=1
    while [ "$i" -le "${GNG_NUM}" ]; do
        pidfile=`echo ${GNG_PIDFILE_TPL} | sed "s/XX/$i/g"`
        logfile=`echo ${GNG_LOG_TPL} | sed "s/XX/$i/g"`

        ${GNG} -q ${GNG_OPTIONS} -l ${logfile} -4 GNG${GNG_NUM} -p ${pidfile}
        echo "Starting GNG #${i} ..."

        i=`expr $i + 1`
    done

    echo "Pausing for ${WAIT_SEC} second(s)."
    sleep ${WAIT_SEC}

    gws_pid=`${CAT} ${GWS_PIDFILE} 2>/dev/null`
    if [ $? -eq 0 ] && kill -0 ${gws_pid}; then
        echo "GWS [${gws_pid}] STARTED"
    else
        errmsg "GWS [${gws_pid}] FAILED"
    fi

    ng_err=0; i=1
    while [ "$i" -le "${GNG_NUM}" ]; do
        pidfile=`echo ${GNG_PIDFILE_TPL} | sed "s/XX/$i/g"`
        gng_pid=`$CAT ${pidfile}`
        if kill -0 ${gng_pid} 2>/dev/null; then
            echo "GNG [${gng_pid}] STARTED"
        else
            echo "GNG [${gng_pid}] FAILED"
            ng_err=1
        fi

        i=`expr $i + 1`
    done

    if [ "$ng_err" -gt 0 ]; then
        echo "$0: some GNG's could not start, shutting down GWS."
        kill ${gws_pid}
    fi
}

gxy_status()
{
    check_pidfile ${GWS_PIDFILE} 'GWS' || return 1

    ls ${GPX_PIDFILE_DIR}/gng*.pid 2>/dev/null | while read fname; do
        check_pidfile ${fname} 'GNG'
    done
}


gxy_stop()
{
    check_pidfile ${GWS_PIDFILE} 'GWS' || return 1
    if kill ${pid}; then
        echo "GWS [${pid}] stopped."
    else
        echo "GWS [${pid}] FAILED to stop."
    fi

    # if ws.ng.force_shutdown is enabled, GNG's should quit.
    sleep ${WAIT_SEC}

    ls ${GPX_PIDFILE_DIR}/gng*.pid 2>/dev/null | while read fname; do
        check_pidfile ${fname} 'GNG' || return 1
        if kill ${pid}; then
            echo "GNG [${pid}] stopped."
        else
            echo "GNG [${pid}] FAILED to stop."
        fi
    done
}


#############################
# Main
#############################

[ $# -lt 1 ] && usage $0

check_prerequisites

case "$1" in
    'start'|'START')
        ngnum=1
        if [ $# -ge 2 ]; then
            # Number of (gng) engines to launch.
            ngnum=`expr $2 + 0 2>/dev/null`
            [ $? -ne 0 ] && errmsg "$0: invalid parameter format."
            if [ ${ngnum} -lt 1 -o ${ngnum} -gt 64 ]; then
                errmsg "$0: num [${ngnum}] is out of range."
            fi
        fi
        gxy_start ${ngnum}
        ;;

    'stop'|'STOP')
        gxy_stop
        ;;

    'status'|'STATUS')
        gxy_status
        ;;
    *) errmsg "Unrecognized command: $1" ;;
esac


# __EOF__
